@@ -24,8 +24,8 @@
 #' @importFrom utils capture.output tail
 #' @author Przemysław Biecek, Magda Tatarynowicz, Kamil Romaszko, Mateusz Urbański
 #' @examples
-#'
-#' require("DALEX")
+#' \donttest{
+#' require("ranger")
 #' require("breakDown")
 #' require("DALEX")
 #'
@@ -44,7 +44,6 @@
 #'                      vr.vars= c("average_montly_hours"),
 #'                      vr.type = "ale")
 #'
-#' \donttest{
 #' # More complex example with all modules
 #' HR_ranger_model <- ranger(as.factor(left) ~ .,
 #'                       data = HR_data, num.trees = 500, classification = TRUE, probability = TRUE)
@@ -75,7 +74,7 @@ modelDown <- function(...,
                       modules = c("auditor", "drifter", "model_performance", "variable_importance", "variable_response"),
                       output_folder="output",
                       repository_name="repository",
-                      should_open_website=TRUE) {
+                      should_open_website=interactive()) {
 
   args <- list(..., version=1.0 )
   #named arguments are options (except those specified after ... in function definition)
